@@ -162,15 +162,11 @@ def get_monitoring_services(request):
 
 
 def show_by_dimension(data, dim_name):
-    if 'metrics' in data:
-        dimensions = []
-        for metric in data['metrics']:
-            if 'dimensions' in metric:
-                if dim_name in metric['dimensions']:
-                    dimensions.append(str(metric['dimensions'][dim_name].encode('utf-8')))
-
-        return dimensions
-    return []
+    if 'dimensions' in data['metrics'][0]:
+        dimensions = data['metrics'][0]['dimensions']
+        if dim_name in dimensions:
+            return str(data['metrics'][0]['dimensions'][dim_name].encode('utf-8'))
+    return ""
 
 
 def get_status(alarms):
@@ -202,11 +198,10 @@ def generate_status(request):
         if 'groupBy' in row:
             alarms_by_group = {}
             for a in alarms:
-                groups = show_by_dimension(a, row['groupBy'])
-                if groups:
-                    for group in groups:
-                        group_alarms = alarms_by_group.setdefault(group, [])
-                        group_alarms.append(a)
+                group = show_by_dimension(a, row['groupBy'])
+                if group:
+                    group_alarms = alarms_by_group.setdefault(group, [])
+                    group_alarms.append(a)
             services = []
             for group, group_alarms in alarms_by_group.items():
                 name = '%s=%s' % (row['groupBy'], group)
@@ -245,10 +240,14 @@ class IndexView(TemplateView):
             api_root = self.request.build_absolute_uri(proxy_url_path)
             context["api"] = api_root
         context["dashboards"] = get_dashboard_links(self.request)
+        # Ensure all links have a 'raw' attribute
+        for link in context["dashboards"]:
+            link['raw'] = link.get('raw', False)
         context['can_access_logs'] = policy.check(
             ((getattr(settings, 'KIBANA_POLICY_SCOPE'), getattr(settings, 'KIBANA_POLICY_RULE')), ), self.request
         )
         context['enable_kibana_button'] = settings.ENABLE_KIBANA_BUTTON
+        context['show_grafana_home'] = settings.SHOW_GRAFANA_HOME
         return context
 
 
